@@ -50,8 +50,6 @@ extern "C" {
 }
 #endif /* not STDLIB_H_DECLARES_PUTENV */
 
-const char *strsignal(int);
-
 const int SOELIM_INDEX = 0;
 const int REFER_INDEX = SOELIM_INDEX + 1;
 const int PIC_INDEX = REFER_INDEX + 1;
@@ -92,7 +90,7 @@ void print_commands();
 void append_arg_to_string(const char *arg, string &str);
 void handle_unknown_desc_command(const char *command, const char *arg,
 				 const char *filename, int lineno);
-const char *basename(const char *);
+/* const char *basename(const char *); */
 
 void usage();
 void help();
@@ -309,9 +307,10 @@ int main(int argc, char **argv)
     print_commands();
     exit(0);
   }
-  exit(run_commands());
+  return run_commands();
 }
 
+#if 0
 const char *basename(const char *s)
 {
   if (!s)
@@ -319,6 +318,7 @@ const char *basename(const char *s)
   const char *p = strrchr(s, '/');
   return p ? p + 1 : s;
 }
+#endif
 
 void handle_unknown_desc_command(const char *command, const char *arg,
 				 const char *filename, int lineno)
